Interface: DoughnutAnimationOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: DoughnutAnimationOptions

## # Properties

### # animateRotate

• animateRotate: `boolean`

If true, the chart will animate in with a rotation animation. This property is in the options.animation object.

`default` true

#### # Defined in

index.esm.d.ts:282
(opens new window)

### # animateScale

• animateScale: `boolean`

If true, will animate scaling the chart from the center outwards.

`default` false

#### # Defined in

index.esm.d.ts:288
(opens new window)